@@ -4,11 +4,10 @@ from sqlalchemy import (DATETIME, JSON, Column, Float, Identity, Integer,
 
 
 class StrategyTable(BaseTable):
-    
 
-    def __init__(self,table_name = "strategy", *args, **kwargs):
-        super(StrategyTable, self).__init__(table_name,*args, **kwargs)
-        self.table = Table(self.table_name,self.meta,
+    def __init__(self, table_name="strategy", *args, **kwargs):
+        super(StrategyTable, self).__init__(table_name, *args, **kwargs)
+        self.table = Table(self.table_name, self.meta,
                            Column('id', Integer, Identity(start=42, cycle=True), comment='自增ID', primary_key=True),
                            Column('gmt_create', DATETIME, comment='创建时间', server_default=text('NOW()')),
                            Column('gmt_modified', DATETIME, comment='修改时间',
@@ -17,8 +16,10 @@ class StrategyTable(BaseTable):
                            Column('ext_json', JSON, comment='拓展'),
                            Column('symbol', String(30), comment='symbol'),
                            Column('amount', Float, comment='amount'),
-                           Column('buy_price', Float, comment='买入价格'),
-                           Column('sell_price', Float, comment='卖出价格'),
+                           Column('buy_json', JSON, comment='买入信息'),
+                           Column('sell_json', JSON, comment='卖出信息'),
+                           Column('strategy1', JSON, comment='策略1'),
+
                            extend_existing=True,
                            # autoload=True
                            )
